stereo.preprocess.Normalizer
============================

.. currentmodule:: stereo.preprocess

.. autoclass:: Normalizer

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Normalizer.__init__
      ~Normalizer.add_result
      ~Normalizer.check_param
      ~Normalizer.fit
      ~Normalizer.get_params
      ~Normalizer.sparse2array
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Normalizer.methods
   
   